#1ReadData.R

#Read in the data analyzed in this published paper:
#New methods for quantifying the effects of catchment spatial patterns on aquatic responses
#by Donald E. Weller, Matthew E. Baker, and Ryan S. King
#Landscape Ecology https://doi.org/10.1007/s10980-023-01706-x

#Don Weller, wellerd@si.edu, Smithsonian Environmental Research Center, Edgewater, MD  21037
#last tested with Windows 10 RStudio 2023.06.0+421 "Mountain Hydrangea"
#and R version 4.3.0 (2023-04-21 ucrt) "Already Tomorrow"
#June 2023

library(plyr)

#read in PCB data concentration data from .csv file
pcb <- read.csv(".\\SubestuaryPCB.csv")
#sort by id so residuals match up later in cbind
pcb <- pcb[order(pcb$id),]  

#read in the distances, the variables are JUNK COUNT ID DISTANCE
#distances are commercial(actually commercial/industrial), highres (high density resdential), lowres (low density residental), total (all land)
cd <- read.csv(".\\cdist.csv",header=F)[2:4]
names(cd) <- c("cc","id","d")
hd <- read.csv(".\\hdist.csv",header=F)[2:4]
names(hd) <- c("hc","id","d")
ld <- read.csv(".\\ldist.csv",header=F)[2:4]
names(ld) <- c("lc","id","d")
td <- read.csv(".\\tdist.csv",header=F)[2:4]
names(td) <- c("tc","id","d")
ad1 <- merge(cd,hd,by=c("id","d"),all=T)
ad2 <- merge(ad1,ld,by=c("id","d"),all=T)
ad <- merge(ad2,td,by=c("id","d"),all=T)
ad <- ad[!is.na(ad$tc),]  #delete if total count is NA
ad[is.na(ad$cc),"cc"] <- 0 #set NA counts to zero
ad[is.na(ad$hc),"hc"] <- 0
ad[is.na(ad$lc),"lc"] <- 0
ad$d <- ad$d*10 #conv to meters (distahces were divided by 10 in ArcGIS for binning)
####commented out the following because King et al. used the max distance in a band
####and that's what these files already give
####ad$d <-ad$d + 5 #use midpoint of 10 m bin
#
# must combine 3 ASC segments (Patapsco, Gwynns Falls, Jones Falls) into 1 bigger segment PatGwynJon to
# match observed concentration data
ad[ad$id==1|ad$id==2|ad$id==5,"id"] <- 32
ad3 <- ddply( ad, .(id,d), colwise(sum,c("cc","hc","lc","tc")) )
#use merge to pick out just the 14 subestuaries with PCB data
ad4 <- merge(ad3,pcb["id"],by="id",all.y=T)
#and sort by id and distance so residuals match up later in cbind
ad4 <- ad4[order(ad4$id,ad4$d),]
#convert pixel counts to areas in ha (30x30 m pixels)
ad4 <- within(ad4,{
  cc = cc*30*30/10000
  hc = hc*30*30/10000
  lc = lc*30*30/10000
  tc = tc*30*30/10000
})
#get the sums of the areas for each subestuary 
adsum <- ddply(ad4, .(id), colwise(sum,c("cc","hc","lc","tc")))

rm(cd,hd,ld,td,ad,ad1,ad2,ad3)  ##clean up to free memory

#at this point there are 3 data frames left
#pcb has the observed avg PCB levels in fish for 14 subestuaries (varibles id, segment, and pcb); pcb in ng per gram of fish tissue;
#    segment is the name of each subestuary, id is a unique identifying number
#ad4 has for each distance band in each subestuary (id), the areas of commerical (cc), high density developed (hc), and low density developed (lc) land use as well as
#    the total land area (tc) at that distance; areas are in ha
#adsum has the sums of the same areas (cc, hc, lc, and tc) for each of the 14 subestuaries (id)
